local L = LibStub("AceLocale-3.0"):GetLocale("WorldBossStatus")
WorldBossStatus = LibStub("AceAddon-3.0"):NewAddon("WorldBossStatus", "AceConsole-3.0", "AceEvent-3.0" );

local addonName = "WordBossStatus";
local LDB = LibStub("LibDataBroker-1.1", true)
local LDBIcon = LDB and LibStub("LibDBIcon-1.0", true)

local ShaDefeted = false
local GalleonDefeated = false

local Status = {}
Status[0] = L["Undefeated"]
Status[1] = L["Defeated"]

local Colors = {}
Colors[0] = "FF00FF00"
Colors[1] = "FFFF0000"


local WorldBossStatusLauncher = LDB:NewDataObject(addonName, {
		type = "launcher",
		icon = "Interface\\Icons\\Achievement_BG_KillXEnemies_GeneralsRoom",
		OnClick = function(clickedframe, button)
			WorldBossStatus:ShowOptions() 
		end,
		OnTooltipShow = function(tt)
			WorldBossStatus:GetStatus()
			tt:SetText(L["World Boss Status"])				
			tt:AddLine(" ")
			tt:AddDoubleLine(L["Sha of Anger"]..":", Status[ShaDefeated and 1 or 0], 1, 1, 1, ShaDefeated and 1 or 0, not ShaDefeated and 1 or 0, 0)
			tt:AddDoubleLine(L["Galleon"]..":", Status[GalleonDefeated and 1 or 0], 1, 1, 1, GalleonDefeated and 1 or 0, not GalleonDefeated and 1 or 0, 0)
			tt:AddLine(" ")
			tt:AddLine(L["Click to open the options menu"])
		end,
	})

local defaults = {
	global = {
		MinimapButton = {
			hide = false,
		}, 
	},
};

local options = {
    name = L["World Boss Status"],
    handler = WorldBossStatus,
    type = "group",
    args = {
        showMiniMapButton = {
            type = "toggle",
            name = L["Minimap Button"],
            desc = L["Toggles the display of the minimap button."],
            get = "IsShowMinimapButton",
            set = "ToggleMinimapButton",
        },
    },
}

function WorldBossStatus:IsShowMinimapButton(info)
	return not self.db.global.MinimapButton.hide
end

function WorldBossStatus:ToggleMinimapButton(info, value)
	self.db.global.MinimapButton.hide = not value
end
	
function WorldBossStatus:GetStatus()
	ShaDefeated = IsQuestFlaggedCompleted(32099)
	GalleonDefeated = IsQuestFlaggedCompleted(32098)	
end

function WorldBossStatus:ShowOptions()
	InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
end

function WorldBossStatus:OnInitialize()	
	self.db = LibStub("AceDB-3.0"):New("WorldBossStatusDB", defaults, true)

	WorldBossStatus:GetStatus();
	LDBIcon:Register(addonName, WorldBossStatusLauncher, self.db.global.MinimapButton)
	WorldBossStatus:RegisterChatCommand("wbs", "ChatCommandHandler")
	LibStub("AceConfig-3.0"):RegisterOptionsTable(L["World Boss Status"], options)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions(L["World Boss Status"], L["World Boss Status"])

end

function WorldBossStatus:ChatCommandHandler(input)
  if not input or input:trim() == "" then
		WorldBossStatus:ShowStatusInChatWindow()  
    else 
        WorldBossStatus:ShowOptions()
    end
end

function WorldBossStatus:ShowStatusInChatWindow()
    WorldBossStatus:GetStatus()
	self:Print(L["Sha of Anger"]..": |c" .. Colors[ShaDefeated and 1 or 0] .. Status[ShaDefeated and 1 or 0] .."|r")
	self:Print(L["Galleon"]..": |c" .. Colors[GalleonDefeated and 1 or 0] .. Status[GalleonDefeated and 1 or 0] .. "|r")
end

function WorldBossStatus:OnEnable()
	-- Called when the addon is enabled
end

function WorldBossStatus:OnDisable()
    -- Called when the addon is disabled
end
